;; Contains the Scheme stuff which returns an URL to an HTML documentation page.
;; Main function: (w3-html4-url tag).
;; Relies of the LAML library general.

; This URL prefix must be defined in the context of this library. Ends in a forward slash.
(define w3-html4-url-prefix #f)

(define (w3-html4-url tag)
 (let ((tag-specific-url-part (url-part-of-tag tag html-element-map)))
  (if (not w3-html4-url-prefix)
      (error "w3-html4-url: You must define the variable w3-html4-url your self after loading the html-map library."))
  (string-append w3-html4-url-prefix tag-specific-url-part "." "html" "#" "edef" "-" (upcase-string tag))))

(define (url-part-of-tag tag element-map)
  (let ((res (assoc (downcase-string tag) element-map)))
    (if (and res (pair? res) (>= (length res) 2))
        (cadr res)
        (error (string-append "ulr-part-of-tag: unknown tag: " (as-string tag))))))
        

(define html-element-map
 '(
   ("a" "struct/links")
   ("abbr" "struct/text")
   ("acronym" "struct/text")
   ("address" "struct/global")
   ("applet" "struct/objects")
   ("area" "struct/text")
   ("b" "present/graphics")
   ("base" "struct/links")
   ("basefont" "present/graphics")
   ("bdo" "struct/dirlang")
   ("big" "present/graphics")
   ("blockquote" "struct/text")
   ("body" "struct/global")
   ("br" "struct/text")
   ("button" "interact/forms")
   ("caption" "struct/tables")
   ("center" "present/graphics")
   ("cite" "struct/text")
   ("code" "struct/text")
   ("col" "struct/tables")
   ("colgroup" "struct/tables")
   ("dd" "struct/lists")
   ("del" "struct/text")
   ("dfn" "struct/text")
   ("dir" "struct/lists")
   ("div" "struct/global")
   ("dl" "struct/lists")
   ("dt" "struct/lists")
   ("em" "struct/text")
   ("fieldset" "interact/forms")
   ("font" "present/graphics")
   ("form" "interact/forms")
   ("frame" "present/frames")
   ("frameset" "present/frames")
   ("h1" "struct/global")
   ("h2" "struct/global")
   ("h3" "struct/global")
   ("h4" "present/frames")
   ("h5" "present/frames")
   ("h6" "present/frames")
   ("head" "struct/global")
   ("hr" "present/graphics")
   ("html" "struct/global")
   ("i" "present/graphics")
   ("iframe" "present/frames")
   ("img" "struct/objects")
   ("input" "interact/forms")
   ("ins" "struct/text")
   ("isindex" "interact/forms")
   ("kbd" "struct/text")
   ("label" "interact/forms")
   ("legend" "interact/forms")
   ("li" "struct/lists")
   ("link" "struct/links")
   ("map" "struct/objects")
   ("menu" "struct/lists")
   ("meta" "struct/global")
   ("noframes" "present/frames")
   ("noscript" "interact/scripts")
   ("object" "struct/objects")
   ("ol" "struct/lists")
   ("optgroup" "interact/forms")
   ("option" "interact/forms")
   ("p" "struct/text")
   ("param" "struct/objects")
   ("pre" "struct/text")
   ("q" "struct/text")
   ("s" "present/graphics")
   ("samp" "struct/text")
   ("script" "interact/scripts")
   ("select" "interact/forms")
   ("small" "present/graphics")
   ("span" "struct/global")
   ("strike" "present/graphics")
   ("strong" "struct/text")
   ("style" "present/styles")
   ("sub" "struct/text")
   ("sup" "struct/text")
   ("table" "struct/tables")
   ("tbody" "struct/tables")
   ("td" "struct/tables")
   ("textarea" "interact/forms")
   ("tfoot" "struct/tables")
   ("th" "struct/tables")
   ("thead" "struct/tables")
   ("title" "struct/global")
   ("tr" "struct/tables")
   ("tt" "present/graphics")
   ("u" "present/graphics")
   ("ul" "struct/lists")
   ("var" "struct/text")
 ))